@@ -25,7 +25,7 @@ pub struct ArrowFileSystemHandler {
 #[pymethods]
 impl ArrowFileSystemHandler {
     #[new]
-    #[args(options = "None")]
+    #[pyo3(signature = (root, options = None))]
     fn new(root: String, options: Option<HashMap<String, String>>) -> PyResult<Self> {
         let inner = ObjectStoreBuilder::new(root.clone())
             .with_path_as_prefix(true)
@@ -137,7 +137,7 @@ impl ArrowFileSystemHandler {
         Ok(infos)
     }
 
-    #[args(allow_not_found = "false", recursive = "false")]
+    #[pyo3(signature = (base_dir, allow_not_found = false, recursive = false))]
     fn get_file_info_selector<'py>(
         &self,
         base_dir: String,
@@ -230,7 +230,7 @@ impl ArrowFileSystemHandler {
         Ok(file)
     }
 
-    #[args(metadata = "None")]
+    #[pyo3(signature = (path, metadata = None))]
     fn open_output_stream(
         &self,
         path: String,
@@ -352,7 +352,7 @@ impl ObjectInputFile {
         Ok(self.content_length)
     }
 
-    #[args(whence = "0")]
+    #[pyo3(signature = (offset, whence = 0))]
     fn seek(&mut self, offset: i64, whence: i64) -> PyResult<i64> {
         self.check_closed()?;
         self.check_position(offset, "seek")?;
@@ -378,7 +378,7 @@ impl ObjectInputFile {
         Ok(self.pos)
     }
 
-    #[args(nbytes = "None")]
+    #[pyo3(signature = (nbytes = None))]
     fn read(&mut self, nbytes: Option<i64>) -> PyResult<Py<PyBytes>> {
         self.check_closed()?;
         let range = match nbytes {
@@ -512,13 +512,11 @@ impl ObjectOutputStream {
         Err(PyNotImplementedError::new_err("'size' not implemented"))
     }
 
-    #[args(whence = "0")]
     fn seek(&mut self, _offset: i64, _whence: i64) -> PyResult<i64> {
         self.check_closed()?;
         Err(PyNotImplementedError::new_err("'seek' not implemented"))
     }
 
-    #[args(nbytes = "None")]
     fn read(&mut self, _nbytes: Option<i64>) -> PyResult<()> {
         self.check_closed()?;
         Err(PyNotImplementedError::new_err("'read' not implemented"))
